pub struct GoogleCloudDatacatalogV1DatabaseTableSpecDatabaseViewSpec {
pub base_table: Option<String>,
pub sql_query: Option<String>,
pub view_type: Option<String>,
}Expand description
Specification that applies to database view.
This type is not used in any activity, and only used as part of another schema.
Fields
base_table: Option<String>Name of a singular table this view reflects one to one.
sql_query: Option<String>SQL query used to generate this view.
view_type: Option<String>Type of this view.