pub struct GoogleCloudDatacatalogV1GraphSpecGraphElementTable {
pub alias: Option<String>,
pub data_source: Option<String>,
pub destination_node_reference: Option<GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference>,
pub dynamic_label_column: Option<String>,
pub dynamic_properties_column: Option<String>,
pub element_keys: Option<Vec<String>>,
pub input_source: Option<String>,
pub kind: Option<String>,
pub label_and_properties: Option<Vec<GoogleCloudDatacatalogV1GraphSpecGraphElementTableLabelAndProperties>>,
pub source_node_reference: Option<GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference>,
}Expand description
Element table definition.
This type is not used in any activity, and only used as part of another schema.
Fields
alias: Option<String>Required. The alias name of the graph element.
data_source: Option<String>Required. The name of the data source. This is either a table name or a view name that is used for graph element input source. E.g. Person table or PersonView view.
destination_node_reference: Option<GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference>Optional. The destination node reference of the edge.
dynamic_label_column: Option<String>Optional. If set, this is the input column for dynamic label in schemaless data model.
dynamic_properties_column: Option<String>Optional. If set, this is the input column for dynamic properties in schemaless data model.
element_keys: Option<Vec<String>>Required. The name of the keys of the elements in the table.
input_source: Option<String>Required. The input source of the graph element.
kind: Option<String>Required. The kind of the graph element.
label_and_properties: Option<Vec<GoogleCloudDatacatalogV1GraphSpecGraphElementTableLabelAndProperties>>Required. The labels and their properties for the graph element.
source_node_reference: Option<GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference>Optional. The source node reference of the edge.