GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference

Struct GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference 

pub struct GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference {
    pub edge_table_columns: Option<Vec<String>>,
    pub node_alias: Option<String>,
    pub node_table_columns: Option<Vec<String>>,
}
A reference to a source or destination node in a graph edge.

This type is not used in any activity, and only used as part of another schema.

Fields

edge_table_columns: Option<Vec<String>>

Required. The referencing columns in the edge table. The size of edge_table_columns must be equal to the size of node_table_columns.

node_alias: Option<String>

Required. The reference to the source/destination node of the edge. This name must be a valid alias of a node element in the same graph. Example, Person node can be a source node name of an edge element Person_to_Address.

node_table_columns: Option<Vec<String>>

Required. The referenced columns of the source node table.