pub struct GoogleCloudDatacatalogV1GraphSpecGraphElementTableLabelAndProperties {
pub label: Option<String>,
pub properties: Option<Vec<GoogleCloudDatacatalogV1GraphSpecGraphElementTableProperty>>,
}Expand description
The label and its properties. Each label is associated with a set of properties.
This type is not used in any activity, and only used as part of another schema.
Fields
label: Option<String>Required. The name of the label.
properties: Option<Vec<GoogleCloudDatacatalogV1GraphSpecGraphElementTableProperty>>Optional. The properties associated with the label.