pub struct GoogleCloudDatacatalogV1ModifyEntryOverviewRequest {
pub entry_overview: Option<GoogleCloudDatacatalogV1EntryOverview>,
}Expand description
Request message for ModifyEntryOverview.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
entry_overview: Option<GoogleCloudDatacatalogV1EntryOverview>Required. The new value for the Entry Overview.