OrganizationMethods

Struct OrganizationMethods 

pub struct OrganizationMethods<'a, C>
where C: 'a,
{ /* private fields */ }
A builder providing access to all methods supported on organization resources. It is not used directly, but through the DataCatalog hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate google_datacatalog1 as datacatalog1;

use datacatalog1::{DataCatalog, FieldMask, hyper_rustls, hyper_util, yup_oauth2};

let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
    .with_native_roots()
    .unwrap()
    .https_only()
    .enable_http2()
    .build();

let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
    secret,
    yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
    yup_oauth2::client::CustomHyperClientBuilder::from(
        hyper_util::client::legacy::Client::builder(executor).build(connector),
    ),
).build().await.unwrap();

let client = hyper_util::client::legacy::Client::builder(
    hyper_util::rt::TokioExecutor::new()
)
.build(
    hyper_rustls::HttpsConnectorBuilder::new()
        .with_native_roots()
        .unwrap()
        .https_or_http()
        .enable_http2()
        .build()
);
let mut hub = DataCatalog::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `locations_retrieve_config(...)`, `locations_retrieve_effective_config(...)` and `locations_set_config(...)`
// to build up your call.
let rb = hub.organizations();

Implementations

Source

impl<'a, C> OrganizationMethods<'a, C>

pub fn locations_retrieve_config( &self, name: &str, ) -> OrganizationLocationRetrieveConfigCall<'a, C>

Create a builder to help you perform the following task:

Retrieves the configuration related to the migration from Data Catalog to Dataplex Universal Catalog for a specific organization, including all the projects under it which have a separate configuration set.

Arguments
  • name - Required. The organization whose config is being retrieved.
pub fn locations_retrieve_effective_config( &self, name: &str, ) -> OrganizationLocationRetrieveEffectiveConfigCall<'a, C>

Create a builder to help you perform the following task:

Retrieves the effective configuration related to the migration from Data Catalog to Dataplex Universal Catalog for a specific organization or project. If there is no specific configuration set for the resource, the setting is checked hierarchicahlly through the ancestors of the resource, starting from the resource itself.

Arguments
  • name - Required. The resource whose effective config is being retrieved.
pub fn locations_set_config( &self, request: GoogleCloudDatacatalogV1SetConfigRequest, name: &str, ) -> OrganizationLocationSetConfigCall<'a, C>

Create a builder to help you perform the following task:

Sets the configuration related to the migration to Dataplex Universal Catalog for an organization or project.

Arguments
  • request - No description provided.
  • name - Required. The organization or project whose config is being specified.